# Manual Accessibility Testing Checklist

This checklist covers aspects of WCAG 2.1 AAA compliance that cannot be fully automated and require manual verification.

## Instructions

1. For each page in the site, go through this checklist
2. Mark each item as:
   - ✅ Pass
   - ❌ Fail
   - N/A Not applicable
3. For any failures, note the specific issue and location

## Pages to Test

- Home page (/)
- Stories index (/stories/)
- Individual story pages (e.g., /stories/open-source-success.html)
- Tools pages (e.g., /one-pager-tools/csv-tool.html)

## Checklist

### Perceivable

#### 1.2.6 Sign Language (AAA)
- [ ] Sign language interpretation is provided for all prerecorded audio content in synchronized media

#### 1.2.7 Extended Audio Description (AAA)
- [ ] Extended audio description is provided for all prerecorded video content

#### 1.2.8 Media Alternative (AAA)
- [ ] Alternative for time-based media is provided for all prerecorded synchronized media and for all prerecorded video-only media

#### 1.2.9 Audio-only (Live) (AAA)
- [ ] Alternative for time-based media that presents equivalent information for live audio-only content is provided

#### 1.3.6 Identify Purpose (AAA)
- [ ] The purpose of UI components, icons, and regions can be programmatically determined

#### 1.4.6 Contrast (Enhanced) (AAA)
- [ ] Visual presentation of text and images of text has a contrast ratio of at least 7:1
- [ ] Large text (over 18pt or 14pt bold) has a contrast ratio of at least 4.5:1

#### 1.4.9 Images of Text (No Exception) (AAA)
- [ ] Images of text are only used for pure decoration or where a particular presentation of text is essential to the information being conveyed

### Operable

#### 2.1.3 Keyboard (No Exception) (AAA)
- [ ] All functionality of the content is operable through a keyboard interface without requiring specific timings for individual keystrokes

#### 2.2.3 No Timing (AAA)
- [ ] Timing is not an essential part of the event or activity presented by the content

#### 2.2.4 Interruptions (AAA)
- [ ] Interruptions can be postponed or suppressed by the user

#### 2.2.5 Re-authenticating (AAA)
- [ ] When an authenticated session expires, the user can continue the activity without loss of data after re-authenticating

#### 2.2.6 Timeouts (AAA)
- [ ] Users are warned of the duration of any user inactivity that could cause data loss

#### 2.3.2 Three Flashes (AAA)
- [ ] Web pages do not contain anything that flashes more than three times in any one second period

#### 2.3.3 Animation from Interactions (AAA)
- [ ] Motion animation triggered by interaction can be disabled

#### 2.4.8 Location (AAA)
- [ ] Information about the user's location within a set of web pages is available

#### 2.4.9 Link Purpose (Link Only) (AAA)
- [ ] A mechanism is available to allow the purpose of each link to be identified from link text alone

#### 2.4.10 Section Headings (AAA)
- [ ] Section headings are used to organize the content

#### 2.5.5 Target Size (AAA)
- [ ] The size of the target for pointer inputs is at least 44 by 44 CSS pixels

#### 2.5.6 Concurrent Input Mechanisms (AAA)
- [ ] Web content does not restrict use of input modalities available on a platform

### Understandable

#### 3.1.3 Unusual Words (AAA)
- [ ] A mechanism is available for identifying specific definitions of words or phrases used in an unusual or restricted way

#### 3.1.4 Abbreviations (AAA)
- [ ] A mechanism for identifying the expanded form or meaning of abbreviations is available

#### 3.1.5 Reading Level (AAA)
- [ ] When text requires reading ability more advanced than the lower secondary education level, supplemental content is available

#### 3.1.6 Pronunciation (AAA)
- [ ] A mechanism is available for identifying specific pronunciation of words where meaning is ambiguous without knowing the pronunciation

#### 3.2.5 Change on Request (AAA)
- [ ] Changes of context are initiated only by user request or a mechanism is available to turn off such changes

#### 3.3.5 Help (AAA)
- [ ] Context-sensitive help is available

#### 3.3.6 Error Prevention (All) (AAA)
- [ ] For web pages that require the user to submit information, at least one of the following is true:
  - Submissions are reversible
  - Data entered by the user is checked for input errors and the user is provided an opportunity to correct them
  - A mechanism is available for reviewing, confirming, and correcting information before finalizing the submission

## Notes and Issues

<!-- Document any issues found during manual testing here -->

## Tester Information

- Name: 
- Date: 
- Browser/assistive technology used: 
